/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998, 1999, 2000  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_svgaevents_c.h,v 1.2.2.2 2000/10/03 16:00:58 hercules Exp $";
#endif

#include "SDL_svgavideo.h"

/* Variables and functions exported by SDL_sysevents.c to other parts 
   of the native video subsystem (SDL_sysvideo.c)
*/
extern int SVGA_initkeymaps(int fd);
extern void SVGA_mousecallback(int button, int dx, int dy,
                                 int u1,int u2,int u3, int u4);
extern void SVGA_keyboardcallback(int scancode, int pressed);

extern void SVGA_InitOSKeymap(_THIS);
extern void SVGA_PumpEvents(_THIS);
